<template>
    <div class="videoPanel">
        <div class="menutop">
            <div class="menuback" @click="back">
                <i class="el-icon-arrow-left"></i><span>统计</span>
            </div>
            <div class="menutitle">摄像头</div>
        </div>
        <div style="margin-top: 0.2rem" class="videoContainer">
            <div id="videoBar"></div>
        </div>
    </div>
</template>

<script>
import * as echarts from 'echarts';
import store from "@/utils/store.js";
export default {
    name: 'ManholePanel',
    data() {
        return {
            videoData: [3500, 1725, 2947, 8000, 1700, 1200, 2500, 1401, 2100, 1324]
        }
    },
    mounted() {
        this.getBar();
    },
    methods: {
        getBar() {
            let that = this;
            let barChartDom = document.getElementById('videoBar');
            let myBarChart = echarts.init(barChartDom);
            let option = {
                color: ["#FFD700"],
                grid: {
                    x: 40,
                    y: 40,
                    x2: 80
                },
                xAxis: {
                    type: 'category',
                    data: ['荣华街道', '博兴街道', '亦庄镇', '旧宫镇', '瀛海镇', '台湖镇', '马驹桥镇', '青云店镇', '长子营镇', '采育镇'],
                    axisLabel: {
                        interval: 0,
                        rotate: 45,
                        color: "#000"
                    },
                    axisTick: {
                        show: false//不显示坐标轴刻度线
                    },
                    axisLine: {
                        show: true,//不显示坐标轴线
                        lineStyle: {
                            color: "#b7c8eb"
                        }
                    },
                    name: '(行政区划)',
                    nameLocation: 'end',
                    nameTextStyle: {
                        fontSize: 14,
                        color: '#000'
                        // padding: [32, 0, 0, 0]
                    }
                },
                yAxis: {
                    type: 'value',
                    name: '(摄像头数量)',
                    //nameRotate: '90',
                    nameLocation: 'end',
                    nameTextStyle: {
                        fontSize: 14,
                        padding: [0, 0, 0, -10]
                    },
                    axisTick: {
                        show: false//不显示坐标轴刻度线
                    },
                    axisLine: {
                        show: false,//不显示坐标轴线
                    },
                    splitLine: {     //网格线
                        "show": false
                    }
                },
                series: [
                    {
                        data: that.videoData,
                        type: 'bar',
                        barWidth: 6,
                        // barGap:'90%'
                        itemStyle: {  // 使用方法二的写法
                            color: {
                                type: 'linear',
                                x: 0,  //右
                                y: 0,  //下
                                x2: 0,  //左
                                y2: 1,  //上
                                colorStops: [
                                    {
                                        offset: 0,
                                        color: '#9FC3F3 ' // 0% 处的颜色
                                    },
                                    // {
                                    //     offset: 0.7,
                                    //     color: '#2378f7' // 70% 处的颜色
                                    // },
                                    {
                                        offset: 1,
                                        color: '#3460BC ' // 100% 处的颜色
                                    }
                                ]
                            }
                        },
                    }
                ]
            };
            option && myBarChart.setOption(option);
        },
        back() {
            store.setVideoStatisticsShow(false);
        }
    },
}
</script>

<style scoped>
.videoPanel {
    position: absolute;
    color: black;
    width: 100%;
    height: 100%;
    background-color: white;
    z-index: 4001;
}

#videoBar {
    width: 375px;
    height: 320px;
}
.videoContainer{
    padding: 0.1rem 0.1rem; 
}
</style>